@@ -8,6 +8,7 @@ import os
 from django import forms
 from django.conf import settings
 from django.contrib.admin.widgets import RelatedFieldWidgetWrapper
+from django.db import models
 from django.forms import widgets
 from django.forms.util import flatatt
 from django.utils.encoding import smart_unicode
@@ -218,6 +219,25 @@ class ReadOnlyInput(widgets.Input):
         return super(ReadOnlyInput, self).render(name, value, attrs)
 
 
+class ReadOnlyWidget(forms.Widget):
+
+    def __init__(self, original_value, display_value):
+        if display_value is None:
+            display_value = original_value or u''
+        if isinstance(original_value, models.Model):
+            original_value = original_value.pk
+        self.original_value = original_value
+        self.display_value = display_value
+
+        super(ReadOnlyWidget, self).__init__()
+
+    def render(self, name, value, attrs=None):
+        return unicode(self.display_value)
+
+    def value_from_datadict(self, data, files, name):
+        return self.original_value
+
+
 class AJAXAutocompletionWidget(forms.widgets.Widget):
     """Widget to aid the selection of one or multiple item from a long list of possible items. Looks similar than a SelectBoxWidget, but the list of possibilities gets filtered as long as you type. The possibilities could be passed through an array or by an url which will be queried using AJAX.
 
